

set more off

****
*NOTE: Set your directory so that you can call up the relevant datasets as needed
****
*cd "NAME OF DIRECTORY WHERE DATASETS ARE SAVED"



*************************************************************************************************************************

*******
*REPLICATION MATERIAL FOR RESULTS PRESENTED IN BURSZTYN, ET AL. "Understanding Mechanisms Underlying Peer Effects: Evidence from a Field Experiment on Financial Decisions"
*******


***********
* TABLE 1 *
***********

*This table presents means of investor characteristics (medians in the case of investor income) by experimental condition, for the experimental conditions of interest (investor 2's in conditions A, B, C, and A^neg), as well as a test of balance across conditions.

clear *
use Main_Data

*******************************

*To produce the table, we first define programs that will organize the various summary statistics to be presented. This program will present data on means of variables of interest as well as test for equality of means across experimental conditions:


prog define Store2, rclass
args row y
 {
 
 	reg `y' Condition_C Condition_B Condition_A if investor1==0 & investor1_wanted==1 , robust noc
 	
	mat TABLE1[`row',1]=_b[Condition_A]
	mat TABLE1[`row'+1,1]=_se[Condition_A]

	mat TABLE1[`row',2]=_b[Condition_B]
	mat TABLE1[`row'+1,2]=_se[Condition_B]

	mat TABLE1[`row',3]=_b[Condition_C]
	mat TABLE1[`row'+1,3]=_se[Condition_C]

	mat TABLE1[`row',8]=e(N)
		
	test Condition_C =Condition_B=Condition_A
	mat TABLE1[`row',4]=r(p)

	test Condition_B=Condition_A	
	mat TABLE1[`row',5]=r(p)

	test Condition_C=Condition_A	
	mat TABLE1[`row',6]=r(p)

	test Condition_C=Condition_B	
	mat TABLE1[`row',7]=r(p)

			
}
end
*******************************

*******************************

*The next program will present data on medians of variables of interest (in our case, investor income) as well as test for equality of medians across experimental conditions:

prog define Store_median, rclass
args row y
 {

qreg `y' if Condition_A==1
	mat TABLE1[`row',1]=_b[_cons]
	mat TABLE1[`row'+1,1]=_se[_cons]

qreg `y' if Condition_B==1
	mat TABLE1[`row',2]=_b[_cons]
	mat TABLE1[`row'+1,2]=_se[_cons]

qreg `y' if Condition_C==1
	mat TABLE1[`row',3]=_b[_cons]
	mat TABLE1[`row'+1,3]=_se[_cons]

median `y' if investor1==0 & investor1_wanted==1, by(Group)
	mat TABLE1[`row',4]=r(p)

median `y' if investor1==0 & investor1_wanted==1 & (Condition_B+Condition_A==1), by(Group)
	mat TABLE1[`row',5]=r(p)

median `y' if investor1==0 & investor1_wanted==1 & (Condition_C+Condition_A==1), by(Group)
	mat TABLE1[`row',6]=r(p)

median `y' if investor1==0 & investor1_wanted==1 & (Condition_C+Condition_B==1), by(Group)
	mat TABLE1[`row',7]=r(p)



reg `y' Condition_C Condition_B Condition_A if investor1==0 & investor1_wanted==1 , robust noc

	mat TABLE1[`row',8]=e(N)
}
end
*****************************

*We now run the programs defined above on the variables of interest.

*We begin by presenting mean values (and testing for equality of means) of investor age (years), investor gender (a dummy variable, with "male" equal to 1), and investor marital status (a dummy variable with "married" equal to 1, and another dummy variable with "single" equal to 1):


mat TABLE1=J(30,8,.)

local row=1
foreach x in age male married single  {

Store2 `row' `x'


local ++row
local ++row
local ++row
 
}

*Next, we present median values (and test for equality of medians) of investor incomes (measured as monthly incomes in Reais):


Store_median `row' earnings

local ++row
local ++row
local ++row


*Finally, we present mean values (and test for equality of means) of the relationship between investor 2's in the experimental conditions of interest and their associated investor 1's (the relationship measure is a dummy variable with "family" equal to 1):

Store2 `row' family

*Putting this information together, we present Table 1:

mat li TABLE1


*************************************************************************************************************************

***********
* TABLE 2 *
***********

*This table presents our baseline results: we regress a dummy variable indicating that an investor chose to purchase the asset on experimental condition dummy variables and (in columns 2-4) controls. We present the coefficients (and robust standard errors) on the various condition dummy variables (estimated relative to the omitted group, investor 2's in condition A); we also present a test for significant effects of possession beyond social learning by testing the equality of the coefficients on the condition B dummy and the condition C dummy. In columns 1-3, we include only investor 2's, and in column 4 we add investor 1's (when we include investor 1's, we cluster standard errors at the pair level). Note also that when we include investor 1's, we run a weighted regression to account for the difference in cell sizes across groups of investors (running unweighted regressions does not affect any of our results).

clear *
set more off
use Main_data

*******************************

*To produce the table, we first define a program that will organize the regression output to be presented (coefficient estimates, standard errors, number of observations, and r-squared), the test of equality between the coefficients on conditions B and C, and the take-up rate in the omitted category, condition A:


prog define Store, rclass
args column variables y
 {
	local row=1
	foreach x in `variables'  {
		cap mat TABLE2[`row',`column']=_b[`x'] 
		cap mat TABLE2[`row'+1,`column']=_se[`x']
			local ++row
			local ++row		
			local ++row				
	}
	
		mat TABLE2[20,`column']=e(N)
		mat TABLE2[21,`column']=e(r2)
		
		lincom Condition_C - Condition_B
		
		mat TABLE2[14,`column']=r(estimate)
		mat TABLE2[15,`column']=r(se)
				
		reg takeup c if Condition_A==1, noc

		mat TABLE2[17,`column']=_b[c]
		mat TABLE2[18,`column']=_se[c]		
	

}
end
*******************************

*We now run the regressions presented in Table 2:


mat TABLE2=J(21,4,.)

reg takeup Condition_B Condition_C Condition_A_neg if investor1==0, robust
Store 1 "Condition_B Condition_C Condition_A_neg"

xi: reg takeup Condition_B Condition_C Condition_A_neg  i.broker_id if investor1==0, robust
Store 2 "Condition_B Condition_C Condition_A_neg"

xi: reg takeup Condition_B Condition_C Condition_A_neg  i.broker_id  i.office male single married age family if investor1==0, robust
Store 3 "Condition_B Condition_C Condition_A_neg"

xi: reg takeup Condition_B Condition_C Condition_A_neg investor1  i.broker_id  i.office male single married age family [pw=weight], cluster(pair) robust
Store 4 "Condition_B Condition_C Condition_A_neg investor1"

*And, finally, we put this information together and present Table 2:

mat li TABLE2



*************************************************************************************************************************

***********
* TABLE 3 *
***********

*This table presents our estimates of heterogeneous social learning effects depending on the financial sophistication of investor 2's, and of their associated investor 1's. Panel A presents social learning treatment effects estimated from regressions without controls (i.e., comparisons of means) using investor 2's in conditions A and B. In columns 1-2, we estimate separate social learning effects for financially sophisticated and financially unsophisticated investor 2's, respectively. We regress the investment decision dummy variable on a "financially sophisticated" indicator; an interaction between a Condition B indicator and the financially sophisticated indicator; and, an interaction between a Condition B indicator and a "financially unsophisticated" indicator. Column 3 shows the p-value from a test of equal social learning effects for sophisticated and unsophisticated investor 2's. In columns 4-6, we present results analogous to columns 1-3, but studying heterogeneous social learning effects depending on the associated investor 1's financial sophistication, instead of investor 2's financial sophistication. Panel B presents estimated social learning effects from models analogous to those in Panel A, but also including controls. The financial sophistication variable is based on the self-assessment question conducted in the follow-up survey described in the text. Investors rated their financial knowledge from 1 (very low) to 7 (very high). Investors who reported 4 or higher were classified as financially sophisticated. We had to exclude 7 out of 50 investor 2's in conditions A and B from the regressions reported in columns 1-2, because we do not have information on financial sophistication for them. We had to exclude 3 out of 50 investor 2's in conditions A and B from the regressions reported in columns 4-5, because we do not have information on financial sophistication for their associated investor 1's.

clear *
set more off
use Main_data

*******************************

*To produce the table, we first define a program that will organize the regression output to be presented (coefficient estimates, standard errors), the test of equality between the social learning effects across groups of investor 2's, and take-up rates for  investor 2's in Condition A who are sophisticated, and unsophisticated.

prog define Store, rclass
args column group
 {

gen X1=`group'==1
gen X2=`group'==0

foreach i in 1 2 {

gen C2_X`i' = Condition_B*X`i'

}

reg takeup X1 X2 [pw=weight] if Condition_A==1 & `group'!=., robust noc

		cap mat TABLE3[10,`column']=_b[X1] 
		cap mat TABLE3[11,`column']=_se[X1]

		cap mat TABLE3[10,`column'+1]=_b[X2] 
		cap mat TABLE3[11,`column'+1]=_se[X2]

test X1=X2

		cap mat TABLE3[10,`column'+2]=r(p)

reg takeup C2_X1 C2_X2 X1 if  `group'!=. & (Condition_A==1|Condition_B==1), robust

		cap mat TABLE3[1,`column']=_b[C2_X1] 
		cap mat TABLE3[2,`column']=_se[C2_X1]

		cap mat TABLE3[1,`column'+1]=_b[C2_X2] 
		cap mat TABLE3[2,`column'+1]=_se[C2_X2]

		test C2_X1= C2_X2
		cap mat TABLE3[1,`column'+2]=r(p)


xi: reg takeup C2_X*  X1 i.broker_id  i.office male single married age family [pw=weight] if (Condition_A+Condition_B==1) &  `group'!=., robust cluster(pair)

		cap mat TABLE3[6,`column']=_b[C2_X1] 
		cap mat TABLE3[7,`column']=_se[C2_X1]
		
		cap mat TABLE3[6,`column'+1]=_b[C2_X2] 
		cap mat TABLE3[7,`column'+1]=_se[C2_X2]

		test C2_X1= C2_X2
		cap mat TABLE3[6,`column'+2]=r(p)


drop *X1 *X2

}
end
*******************************


mat TABLE3=J(12,7,.)

*Here we use investor 2's own (perceived) financial sophistication as a source of heterogeneity:

Store 1 perceived

****************************************************

*Here we use associated investor 1's (perceived) financial sophistication as a source of heterogeneity:

Store 5 friend_perceived

****************************************************

*And, finally, we put this information together and present Table 3:


mat li TABLE3



*************************************************************************************************************************

*******
*REPLICATION MATERIAL FOR RESULTS PRESENTED IN THE SUPPLEMENTAL ONLINE APPENDIX TO BURSZTYN, ET AL., "Understanding Mechanisms Underlying Peer Effects: Evidence from a Field Experiment on Financial Decisions"
*******



*************
* FIGURE A1 *
*************

*This figure presents the mean (and 95% confidence interval) of the take-up rate for each group of investor 2's.

clear *
set more off
use Main_data

mat R=J(4,4,.)

reg takeup Condition_A Condition_B Condition_C Condition_A_neg if investor1==0, robust noc

local row=1

foreach X in Condition_A Condition_B Condition_C Condition_A_neg   {

mat R[`row',1]=_b[`X']
mat R[`row',2]=_b[`X']-1.96*_se[`X']
mat R[`row',3]=_b[`X']+1.96*_se[`X']
mat R[`row',4]=`row'

local ++row
}

clear
svmat R

la var R4 Group

la var R1 "Take-up rate"


label define groups 1 "Condition {it: A}" 2 "Condition {it: B}"  3 "Condition {it: C}"  4 "Condition {it: A}{sup: {it:neg}}"


label values R4 groups


set scheme s2mono

twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
	   (rcap R3 R2 R4, lc(gs5)), ///
	   legend(off) xlabel(1/4, valuelabel) ///
	   ylabel(0(0.1)1) yscale(range(1))  ///
	   xline(3.5, lpattern(-) lcolor(black)) ///
	   text(0.21 1 "42%") text(0.36 2 "71%") text(0.47 3 "93%") text(0.19 4 "39%") graphregion(color(white))    ytitle("Take-up rate")


*************************************************************************************************************************

*************
* FIGURE A2 *
*************

***************
* Panel A2.1 *
***************

*Panel A.2.1 presents the mean (and 95% confidence interval) of amount invested (Reais) for each group of investor 2's.



clear *
set more off
use Main_data


mat R=J(4,4,.)

reg total_amount Condition_A Condition_B Condition_C Condition_A_neg if investor1==0, robust noc

local row=1

foreach X in Condition_A Condition_B Condition_C Condition_A_neg   {

mat R[`row',1]=_b[`X']
mat R[`row',2]=_b[`X']-1.96*_se[`X']
mat R[`row',3]=_b[`X']+1.96*_se[`X']
mat R[`row',4]=`row'

local ++row
}

clear
svmat R

la var R4 Group

la var R1 "Amount invested"


label define groups 1 "Condition {it: A}" 2 "Condition {it: B}"  3 "Condition {it: C}"  4 "Condition {it: A}{sup: {it:neg}}"


label values R4 groups


set scheme s2mono

twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium)) ///
	   (rcap R3 R2 R4, lc(gs5)), ///
	   legend(off) xlabel(1/4, valuelabel) ///
	   ylabel(0(1000)4000) yscale(range(1))  ///
	   xline(3.5, lpattern(-) lcolor(black)) ///
	   text(440 1 "R$885") text(915 2 "R$1833") text(1760 3 "R$3518") text(340 4 "R$778") graphregion(color(white))  ytitle("Amount invested")


*************************************************************************************************************************

***************
* Panel A2.2 *
***************

*Panel A.2.2 presents the mean (and 95% confidence interval) of a dummy variable equal to one if the investor invested more than the minimum amount for each group of investor 2's.

clear *
set more off
use Main_data

mat R=J(4,4,.)

reg invested_above_minimum Condition_A Condition_B Condition_C Condition_A_neg if investor1==0, robust noc

local row=1

foreach X in Condition_A Condition_B Condition_C Condition_A_neg   {

mat R[`row',1]=_b[`X']
mat R[`row',2]=_b[`X']-1.96*_se[`X']
mat R[`row',3]=_b[`X']+1.96*_se[`X']
mat R[`row',4]=`row'

local ++row
}

clear
svmat R

la var R4 Group

la var R1 "Invested more than minimum amount"


label define groups 1 "Condition {it: A}" 2 "Condition {it: B}"  3 "Condition {it: C}"  4 "Condition {it: A}{sup: {it:neg}}"


label values R4 groups


set scheme s2mono


twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
	   (rcap R3 R2 R4, lc(gs5)), ///
	   legend(off) xlabel(1/4, valuelabel) ///
	   ylabel(0(0.1)1) yscale(range(1))  ///
	   xline(3.5, lpattern(-) lcolor(black)) ///
	   text(0.05 1 "3.8%") text(.125 2 "25%") text(.25 3 "54%") text(0.05 4 "0%") graphregion(color(white))  ytitle("Invested more than minimum amount") 
	   


*************************************************************************************************************************

*************
* FIGURE A3 *
*************

*Panel A.3.1 presents the mean (and 95% confidence intervals) of take-up rates for investor 2's in conditions A and B, separately for those who are and who are not financially sophisticated.
*Panel A.3.2  presents the mean (and 95% confidence intervals) of take-up rates for investor 2's in conditions A and B, separately for those whose associated investor 1's are and are not financially sophisticated.
*In both panels, the financial sophistication variable is based on a self-assessment question conducted in the follow-up survey.

clear *
set more off
use Main_data

*******************************
prog define figure, rclass
args keep investor a1 b1 a2 b2 a3 b3 a4 b4
 {

preserve

mat R=J(4,4,.)

reg takeup Condition_A Condition_B if (Condition_A+Condition_B==1) & `keep'==1, robust noc

local row=1

foreach X in Condition_A Condition_B  {

mat R[`row',1]=_b[`X']
mat R[`row',2]=_b[`X']-1.96*_se[`X']
mat R[`row',3]=_b[`X']+1.96*_se[`X']
mat R[`row',4]=`row'

local ++row
}

reg takeup Condition_A Condition_B if (Condition_A+Condition_B==1) & `keep'==0, robust noc


foreach X in Condition_A Condition_B  {

mat R[`row',1]=_b[`X']
mat R[`row',2]=_b[`X']-1.96*_se[`X']
mat R[`row',3]=_b[`X']+1.96*_se[`X']
mat R[`row',4]=`row'

local ++row
}



clear
svmat R

la var R4 Group

la var R1 "Take-up rate"


label define groups 1 "Condition {it: A}" 2 "Condition {it: B}"  3 "Condition {it: A}"  4 "Condition {it: B}"


label values R4 groups

set scheme s2mono


twoway (bar R1 R4 if inlist(R4,1,2), barw(0.6) fi(inten30) lc(black) lw(medium)  ) ///
	   (bar R1 R4 if inlist(R4,3,4), barw(0.6) fi(inten0) lc(black) lw(medium) ) ///
	   (rcap R3 R2 R4, lc(gs5)), ///
	   legend(off) xlabel(1/4, valuelabel) ///
	   ylabel(0(0.1)1) yscale(range(-0.08 1.1))  ///
	   xline(2.5, lpattern(-) lcolor(black)) ///
	   graphregion(color(white))  saving(`save', replace)  text(`a1' 1 "`b1'%") text(`a2' 2 "`b2'%") text(`a3' 3 "`b3'%") text(`a4' 4 "`b4'%") ///   
       text(1.1 1.5 "Yes") text(1.1 3.5 "No")  ytitle("Take-up rate")
              
restore

}
end	  
	   
figure "perceived"  "Investor 2" 0.23 46 0.22 44 0.17 33 0.46 92 // Figure A.3.1

figure "friend_perceived"  "Associated investor 1" 0.19 39 0.39 77 0.21 43 0.27 56  // Figure A.3.2


*************************************************************************************************************************

*************
* TABLE A1  *
*************

*Table A1 presents characteristics of the entire experimental sample (including investor 1's) and also provides summary statistics for the clients of the brokerage's main office for purposes of comparison.
*This table relies on the "Appendix_data" dataset, as it includes information on investors outside of the experimental sample.

*Column 1 presents the characteristics of the experimental sample, combining investor 1's and investor 2's.
*Column 2 presents the sample characteristics of investor 1's in the experimental sample, while columns 3 and 4 present the information for investor 1's who wanted and who did not want the asset, respectively.
*Column 5 presents the characteristics of investors 2's in the experimental sample, while columns 6 and 7 present the information for investor 2's whose peers wanted and did not want the asset, respectively.
*Column 8 presents the characteristics of the universe of investors in the main office of the brokerage.
*Each line presents averages of the corresponding variable. For earnings, we present the median value instead of the mean due to large outliers. The sample size for the earnings variable is smaller due to missing values.  The omitted value for ``Relationship with associated investor" is "friends". This variable is not defined for investors outside the experiment's sample.


clear *
use Appendix_data


*******************************

*Again, we begin by defining a program that will organize the data we present in the table:

prog define Store1, rclass
args col y
 {
 
 	preserve
 
 	`y'
 
 
	local row=1
	foreach x in  age male married single  {

	 	reg `x' c, robust noc
 	
		mat TABLE_A1[`row',`col']=_b[c]
		mat TABLE_A1[`row'+1,`col']=_se[c]

	local ++row
	local ++row
	local ++row

	}

	 	qreg earnings c
 	
		mat TABLE_A1[`row',`col']=_b[_cons]
		mat TABLE_A1[`row'+1,`col']=_se[_cons]

	local ++row
	local ++row
	local ++row


	 	cap reg family c, robust noc
 	
		cap mat TABLE_A1[`row',`col']=_b[c]
		cap mat TABLE_A1[`row'+1,`col']=_se[c]

	local ++row
	local ++row
	local ++row


	summ age
	
	mat TABLE_A1[`row',`col']=r(N)


			
	restore
	
}
end

*******************************


mat TABLE_A1=J(30,11,.)

Store1 1 "keep if Experimental_sample==1"

Store1 3 "keep if Experimental_sample==1 & investor1==1 "

Store1 4 "keep if Experimental_sample==1 & investor1==1 & takeup==1"

Store1 5 "keep if Experimental_sample==1 & investor1==1 & takeup==0"



Store1 7 "keep if Experimental_sample==1 & investor2==1 "

Store1 8 "keep if Experimental_sample==1 & investor2==1 & investor1_wanted==1"

Store1 9 "keep if Experimental_sample==1 & investor2==1 & investor1_wanted==0"


Store1 11 "keep if Experimental_sample==0"

*We now present Table A.1:

mat li TABLE_A1




*************************************************************************************************************************

************
* TABLE A2 *
************

*This table presents the characteristics of individuals randomly assigned into categories of investor 1 versus investor 2; and, whose purchase decisions were randomly implemented or rejected by lottery.

*Columns 1 and 2 present the averages of the corresponding variable, respectively, for investors assigned to be in the role of investor 1 and for those assigned to be in the role of investor 2. Robust standard errors in parentheses. Relationship with peer is not considered in this comparison since this variable is equal for both groups by construction. Column 3 presents the p-value of an F-test that the mean of the corresponding variable is the same for these two groups. Column 5 presents the averages for investor 1's who wanted the asset and won the lottery, while column 6 presents the averages for investor 1's who wanted the asset but did not win the lottery. Column 7 presents the p-value of an F-test that the mean of the corresponding variable is the same for these two groups. For earnings, we present the median and the p-value of a test that the median of this variable is the same for the corresponding groups. The sample size for the earnings variable is smaller due to missing values.


clear *
use Main_data


*******************************

*Again, we begin by defining a program that will organize the data we present in the table:

prog define Store1, rclass
args row y
 {
 
 	reg `y' investor1 investor2, robust noc
 	
	mat TABLE_A2[`row',1]=_b[investor1]
	mat TABLE_A2[`row'+1,1]=_se[investor1]

	mat TABLE_A2[`row',2]=_b[investor2]
	mat TABLE_A2[`row'+1,2]=_se[investor2]

	mat TABLE_A2[`row',4]=e(N)
		
	test investor1=investor2
	
	mat TABLE_A2[`row',3]=r(p)
	
	 reg `y' authorized not_authorized if investor1==1 & takeup==1, robust noc
 	
	mat TABLE_A2[`row',6]=_b[authorized]
	mat TABLE_A2[`row'+1,6]=_se[authorized]

	mat TABLE_A2[`row',7]=_b[not_authorized]
	mat TABLE_A2[`row'+1,7]=_se[not_authorized]

	mat TABLE_A2[`row',9]=e(N)
		
	test authorized=not_authorized
	
	mat TABLE_A2[`row',8]=r(p)
			
	
			
}
end
*******************************

gen not_authorized=0
replace not_authorized=1 if authorized==0


mat TABLE_A2=J(18,9,.)

local row=1
foreach x in age male married single  {

Store1 `row' `x'


local ++row
local ++row
local ++row
 
}


qreg earnings if investor1==1
	mat TABLE_A2[`row',1]=_b[_cons]
	mat TABLE_A2[`row'+1,1]=_se[_cons]

qreg earnings if investor2==1
	mat TABLE_A2[`row',2]=_b[_cons]
	mat TABLE_A2[`row'+1,2]=_se[_cons]

median earnings , by(investor1)
	mat TABLE_A2[`row',3]=r(p)

reg earnings investor1 investor2, robust noc

	mat TABLE_A2[`row',4]=e(N)

qreg earnings if authorized==1 & investor1==1 & takeup==1
	mat TABLE_A2[`row',6]=_b[_cons]
	mat TABLE_A2[`row'+1,6]=_se[_cons]

qreg earnings if not_authorized==1 & investor1==1 & takeup==1
	mat TABLE_A2[`row',7]=_b[_cons]
	mat TABLE_A2[`row'+1,7]=_se[_cons]

median earnings if investor1==1 & takeup==1 , by(authorized)
	mat TABLE_A2[`row',8]=r(p)

reg earnings authorized not_authorized if investor1==1 & takeup==1, robust noc

	mat TABLE_A2[`row',9]=e(N)


local ++row
local ++row
local ++row


Store1 `row' family

*We now present Table A.2

mat li TABLE_A2





*************************************************************************************************************************

************
* TABLE A3 *
************

*Here we present the responses to the follow-up survey

clear *
use Main_data


sum Fin_lit_Q1

forvalues x=2(1)5 {

tab Fin_lit_Q`x'

}


gen fin_lit =Fin_lit_Q2 + Fin_lit_Q3 + Fin_lit_Q4 + Fin_lit_Q5
tab fin_lit


forvalues x=1(1)12 {

tab Followup_Q`x'

}


*************************************************************************************************************************

************
* TABLE A4 *
************

*Here we present the responses to the follow-up survey, but excluding those surveys in which the surveyor was the broker who made the original experimental sales call:


clear *
use Main_data

drop if followup_match==1


sum Fin_lit_Q1

forvalues x=2(1)5 {

tab Fin_lit_Q`x'

}


gen fin_lit =Fin_lit_Q2 + Fin_lit_Q3 + Fin_lit_Q4 + Fin_lit_Q5
tab fin_lit


forvalues x=1(1)12 {

tab Followup_Q`x'

}



*************************************************************************************************************************

************
* TABLE A5 *
************

*This table replicates the results from Table 2 in the main text of the manuscript, but using Probit models instead of ordinary least squares regressions. The coefficients presented are average marginal effects. Standard errors are bootstrapped and clustered at the pair level in column 4.

/*
	Note: in the paper, we present bootstrapped standard errors using 500 replications. In this do-file, we run only 100 replications so that the program runs faster. In order to replicate the results using 500 replications, one would only have to replace 100 with 500 in the code.
*/


clear *
set more off
use Main_data

set seed 123

tab broker , ge(broker_)
tab office , ge(office_)


mat TABLE_A5=J(30,10,.)


*****************************************************************
prog define store, rclass
args column 
{
	local row=1
	foreach x in _bs_1 _bs_2 _bs_4 _bs_5  {
		cap mat TABLE_A5[`row',`column']=_b[`x'] 
		cap mat TABLE_A5[`row'+1,`column']=_se[`x']
			local ++row
			local ++row		
			local ++row				
	}
					
		mat TABLE_A5[19,`column']=_b[_bs_3]
		mat TABLE_A5[20,`column']=_se[_bs_3]
}
end
*****************************************************************




*****************************************************************
*****************************************************************
prog define estimation1, rclass
args Y 
{

preserve

probit `Y' Condition_B Condition_C Condition_A_neg if investor1==0, robust

gen z=_b[_cons]

gen A=normal(z)
gen B=normal(z+_b[Condition_B])
gen C=normal(z+_b[Condition_C])
gen A_neg=normal(z+_b[Condition_A_neg])

foreach x in A B C A_neg  {
summ `x'
local `x'= r(mean)
}

return scalar learning_alone = `B'-`A'
return scalar learning_and_possession = `C'-`A'
return scalar possession_alone = `C'-`B'
return scalar negative = `A_neg'-`A'

restore

}
end
*****************************************************************

preserve
keep if investor1==0
bootstrap r(learning_alone) r(learning_and_possession) r(possession_alone) r(negative), reps(100): estimation1 takeup
store 1
restore


*****************************************************************
*****************************************************************
prog define estimation2, rclass
args Y 
{

preserve

xi: probit `Y' Condition_B Condition_C Condition_A_neg broker_2-broker_8 if investor1==0, robust

gen z=_b[_cons]

forvalues x=2(1)8 {
 	replace z=z+_b[broker_`x'] if broker_`x'==1
}

gen A=normal(z)
gen B=normal(z+_b[Condition_B])
gen C=normal(z+_b[Condition_C])
gen A_neg=normal(z+_b[Condition_A_neg])

foreach x in A B C A_neg  {
summ `x'
local `x'= r(mean)
}

return scalar learning_alone = `B'-`A'
return scalar learning_and_possession = `C'-`A'
return scalar possession_alone = `C'-`B'
return scalar negative = `A_neg'-`A'

restore

}
end
*****************************************************************

preserve
keep if investor1==0
bootstrap r(learning_alone) r(learning_and_possession) r(possession_alone) r(negative), reps(100): estimation2 takeup
store 2
restore


*****************************************************************
*****************************************************************
prog define estimation3, rclass
args Y 
{

preserve

xi: probit `Y' Condition_B Condition_C Condition_A_neg broker_2-broker_8 office_1-office_4  male single married age family if investor1==0, robust

gen z=_b[_cons]+_b[male]*male+_b[single]*single+_b[married]*married+_b[age]*age+_b[family]*family


forvalues x=2(1)8 {
 	replace z=z+_b[broker_`x'] if broker_`x'==1
}

forvalues x=1(1)4 {
 	replace z=z+_b[office_`x'] if office_`x'==1
}

gen A=normal(z)
gen B=normal(z+_b[Condition_B])
gen C=normal(z+_b[Condition_C])
gen A_neg=normal(z+_b[Condition_A_neg])

foreach x in A B C A_neg  {
summ `x'
local `x'= r(mean)
}

return scalar learning_alone = `B'-`A'
return scalar learning_and_possession = `C'-`A'
return scalar possession_alone = `C'-`B'
return scalar negative = `A_neg'-`A'


restore

}
end
*****************************************************************

preserve
keep if investor1==0
bootstrap r(learning_alone) r(learning_and_possession) r(possession_alone) r(negative), reps(100): estimation3 takeup
store 3
restore

*****************************************************************
*****************************************************************
prog define estimation4, rclass
args Y 
{

preserve

probit `Y' Condition_B Condition_C Condition_A_neg investor1 broker_2-broker_8 office_1-office_4 male single married age family  [pw=weight]

gen z=_b[_cons]+_b[male]*male+_b[single]*single+_b[married]*married+_b[age]*age+_b[family]*family


forvalues x=2(1)8 {
 	replace z=z+_b[broker_`x'] if broker_`x'==1
}

forvalues x=1(1)4 {
 	replace z=z+_b[office_`x'] if office_`x'==1
}


gen A=normal(z)
gen B=normal(z+_b[Condition_B])
gen C=normal(z+_b[Condition_C])
gen A_neg=normal(z+_b[Condition_A_neg])
gen Inv1=normal(z+_b[investor1])


foreach x in A B C A_neg  Inv1 {
summ `x'
local `x'= r(mean)
}

return scalar learning_alone = `B'-`A'
return scalar learning_and_possession = `C'-`A'
return scalar possession_alone = `C'-`B'
return scalar negative = `A_neg'-`A'
return scalar investor1 = `Inv1'-`A'

restore

}
end
*****************************************************************
bootstrap r(learning_alone) r(learning_and_possession) r(possession_alone) r(negative) r(investor1), reps(100) cluster(pair): estimation4 takeup
store 4

mat li TABLE_A5





*************************************************************************************************************************

************
* TABLE A6 *
************

*This table replicates the results from Table 2 in the main text of the manuscript, but using Logit models instead of ordinary least squares regressions. The coefficients presented are average marginal effects. Standard errors are bootstrapped and clustered at the pair level in column 4.

/*
	Note: in the paper, we present bootstrapped standard errors using 500 replications. In this do-file, we run only 100 replications so that the program runs faster. In order to replicate the results using 500 replications, one would only have to replace 100 with 500 in the code.
*/


clear *
set more off
use Main_data

set seed 123

tab broker , ge(broker_)
tab office , ge(office_)


mat TABLE_A6=J(30,10,.)


*****************************************************************
prog define store, rclass
args column 
{
	local row=1
	foreach x in _bs_1 _bs_2 _bs_4 _bs_5  {
		cap mat TABLE_A6[`row',`column']=_b[`x'] 
		cap mat TABLE_A6[`row'+1,`column']=_se[`x']
			local ++row
			local ++row		
			local ++row				
	}
					
		mat TABLE_A6[19,`column']=_b[_bs_3]
		mat TABLE_A6[20,`column']=_se[_bs_3]
}
end
*****************************************************************




*****************************************************************
*****************************************************************
prog define estimation1, rclass
args Y 
{

preserve

logit `Y' Condition_B Condition_C Condition_A_neg if investor1==0, robust

gen z=_b[_cons]

gen A=1/(1+exp(-z))
gen B=1/(1+exp(-z-_b[Condition_B]))
gen C=1/(1+exp(-z-_b[Condition_C]))
gen A_neg=1/(1+exp(-z-_b[Condition_A_neg]))

foreach x in A B C A_neg  {
summ `x'
local `x'= r(mean)
}

return scalar learning_alone = `B'-`A'
return scalar learning_and_possession = `C'-`A'
return scalar possession_alone = `C'-`B'
return scalar negative = `A_neg'-`A'

restore

}
end
*****************************************************************

preserve
keep if investor1==0
bootstrap r(learning_alone) r(learning_and_possession) r(possession_alone) r(negative), reps(100): estimation1 takeup
store 1
restore


*****************************************************************
*****************************************************************
prog define estimation2, rclass
args Y 
{

preserve

xi: logit `Y' Condition_B Condition_C Condition_A_neg broker_2-broker_8 if investor1==0, robust

gen z=_b[_cons]

forvalues x=2(1)8 {
 	replace z=z+_b[broker_`x'] if broker_`x'==1
}

gen A=1/(1+exp(-z))
gen B=1/(1+exp(-z-_b[Condition_B]))
gen C=1/(1+exp(-z-_b[Condition_C]))
gen A_neg=1/(1+exp(-z-_b[Condition_A_neg]))

foreach x in A B C A_neg  {
summ `x'
local `x'= r(mean)
}

return scalar learning_alone = `B'-`A'
return scalar learning_and_possession = `C'-`A'
return scalar possession_alone = `C'-`B'
return scalar negative = `A_neg'-`A'

restore

}
end
*****************************************************************

preserve
keep if investor1==0
bootstrap r(learning_alone) r(learning_and_possession) r(possession_alone) r(negative), reps(100): estimation2 takeup
store 2
restore


*****************************************************************
*****************************************************************
prog define estimation3, rclass
args Y 
{

preserve

xi: logit `Y' Condition_B Condition_C Condition_A_neg broker_2-broker_8 office_1-office_4  male single married age family if investor1==0, robust

gen z=_b[_cons]+_b[male]*male+_b[single]*single+_b[married]*married+_b[age]*age+_b[family]*family


forvalues x=2(1)8 {
 	replace z=z+_b[broker_`x'] if broker_`x'==1
}

forvalues x=1(1)4 {
 	replace z=z+_b[office_`x'] if office_`x'==1
}

gen A=1/(1+exp(-z))
gen B=1/(1+exp(-z-_b[Condition_B]))
gen C=1/(1+exp(-z-_b[Condition_C]))
gen A_neg=1/(1+exp(-z-_b[Condition_A_neg]))

foreach x in A B C A_neg  {
summ `x'
local `x'= r(mean)
}

return scalar learning_alone = `B'-`A'
return scalar learning_and_possession = `C'-`A'
return scalar possession_alone = `C'-`B'
return scalar negative = `A_neg'-`A'


restore

}
end
*****************************************************************

preserve
keep if investor1==0
bootstrap r(learning_alone) r(learning_and_possession) r(possession_alone) r(negative), reps(100): estimation3 takeup
store 3
restore

*****************************************************************
*****************************************************************
prog define estimation4, rclass
args Y 
{

preserve

logit `Y' Condition_B Condition_C Condition_A_neg investor1 broker_2-broker_8 office_1-office_4 male single married age family  [pw=weight]

gen z=_b[_cons]+_b[male]*male+_b[single]*single+_b[married]*married+_b[age]*age+_b[family]*family


forvalues x=2(1)8 {
 	replace z=z+_b[broker_`x'] if broker_`x'==1
}

forvalues x=1(1)4 {
 	replace z=z+_b[office_`x'] if office_`x'==1
}


gen A=1/(1+exp(-z))
gen B=1/(1+exp(-z-_b[Condition_B]))
gen C=1/(1+exp(-z-_b[Condition_C]))
gen A_neg=1/(1+exp(-z-_b[Condition_A_neg]))
gen Inv1=1/(1+exp(-z-_b[investor1]))


foreach x in A B C A_neg  Inv1 {
summ `x'
local `x'= r(mean)
}

return scalar learning_alone = `B'-`A'
return scalar learning_and_possession = `C'-`A'
return scalar possession_alone = `C'-`B'
return scalar negative = `A_neg'-`A'
return scalar investor1 = `Inv1'-`A'

restore

}
end
*****************************************************************
bootstrap r(learning_alone) r(learning_and_possession) r(possession_alone) r(negative) r(investor1), reps(100) cluster(pair): estimation4 takeup
store 4

mat li TABLE_A6




*************************************************************************************************************************


************
* TABLE A7 *
************

*This table presents results using a GMM model, where the overidentifying restriction is that investor 1's take-up rate is a weighted average of investor 2's in conditions A and  \A^neg. More specifically, the moment conditions are: E[Y|Condition C]=c, E[Y|Condition B]=b, E[Y|Condition A]=a, E[Y|Condition A^neg]=n, E[Y|Investor 1]=p, and p = p*a + (1-p)*n.
*Panel A presents the treatment effects of interest, while Panel B presents the GMM coefficients. We also present the p-value of Hansen's J over identifying test. 


clear *
use Main_data

gmm (Condition_B*(takeup-{b})) (Condition_C*(takeup-{c})) ( Condition_A*(takeup-{a}) ) ( Condition_A_neg*(takeup-{n})) (investor1*(takeup-{p})) ({p} - {p}*{a} - (1-{p})*{n}) ,  twostep winitial(unadjusted, independent)   // winicial(identity) 
 
mat li e(b)

nlcom [c]_cons - [a]_cons
nlcom [b]_cons-[a]_cons
nlcom [c]_cons - [b]_cons
nlcom [n]_cons - [a]_cons

estat overid


*************************************************************************************************************************


************
* TABLE A8 *
************

*This table presents the results of two-sided permutation tests with 10,000 replications for the main results in the paper. For each pairwise comparison, we randomly reassign the experimental treatment conditions, drawing treatment assignments (without replacement) in the same ratios as the actual experimental treatment assignments. Based on these "placebo" treatment assignments, we calculate "placebo treatment effects" using 10,000 independent reassignments. The distribution of "placebo treatment effects" from the 10,000 reassignments approximates the distribution of our estimator under the null hypothesis that the treatment effects are zero. We calculate p-values from the permutation tests as the proportion of "placebo treatment effects" that are greater (in absolute value) than the estimated treatment effects using the actual experimental treatment assignments.
*Panel A reports p-values from permutation tests for pairwise comparisons of the conditions of interest using three different outcome variables: take-up rates, amount invested, and a dummy variable indicating whether the investor invested more than the minimum amount.
*Panel B reports p-values from permutation tests for the heterogeneity results using the self-assessed measure of financial literacy.

/*
	Note: in the paper, we present results using 10,000 replications. In this do-file, we run only 1,000 replications so that the program runs faster. In order to replicate the results using 10,000 replications, one would only have to replace 1000 with 10000 in the code.
*/

clear *
use Main_data, clear

set seed 1

set matsize 1000

**************************************
* Condition B - A (permutation test) *
**************************************

mat R=J(1000,3,.)

keep if Condition_B+Condition_A ==1

forvalues row=1(1)1000 {

gen r=runiform()

xtile temp=r , n(50)

gen T = (temp<=24)

reg takeup T
mat R[`row',1]=_b[T]

reg total_amount_invested T
mat R[`row',2]=_b[T]

reg invested_above_minimum T
mat R[`row',3]=_b[T]

drop T temp r

display `row'

}

clear

svmat R

tab R1
gen test1=(R1>=.28 |R1<=-.28)
gen test2=(R2>=948|R2<=-948)
gen test3=(R3>=.21|R3<=-.21)

sum test*   // First row of Table A.6


**************************************
* Condition C - A (permutation test) *
**************************************

use Main_data, clear
set more off

set seed 1 

set matsize 1000
mat R=J(1000,3,.)

keep if Condition_A+Condition_C ==1

forvalues row=1(1)1000 {

gen r=runiform()

xtile temp=r , n(54)

gen T = (temp<=28)


reg takeup T
mat R[`row',1]=_b[T]

reg total_amount_invested T
mat R[`row',2]=_b[T]

reg invested_above_minimum T
mat R[`row',3]=_b[T]


drop T temp r

display `row'

}

clear

svmat R

tab R1


gen test1=(R1>=.50 |R1<=-.50)
gen test2=(R2>=2633|R2<=-2633)
gen test3=(R3>=.49|R3<=-.49)

sum test* // Second row of Table A6


**************************************
* Condition C - B (permutation test) *
**************************************

set seed 1

use Main_data, clear

mat R=J(1000,3,.)

keep if Condition_B+Condition_C ==1

forvalues row=1(1)1000 {

gen r=runiform()

xtile temp=r , n(52)

gen T = (temp<=28)

reg takeup T
mat R[`row',1]=_b[T]

reg total_amount_invested T
mat R[`row',2]=_b[T]

reg invested_above_minimum T
mat R[`row',3]=_b[T]


drop T temp r





display `row'

}

clear

svmat R

gen test1=(R1>=.22 |R1<=-.22)
gen test2=(R2>=1684|R2<=-1684)
gen test3=(R3>=.28|R3<=-.28)

sum test* // Third row of Table A6



********************************************
* Condition A - A_neg (permutation test)   *
********************************************

use Main_data, clear

set seed 1 

set matsize 1000
mat R=J(1000,3,.)

keep if Condition_A + Condition_A_neg ==1

forvalues row=1(1)1000 {

gen r=runiform()

xtile temp=r , n(98)

gen T = (temp<=72)


reg takeup T
mat R[`row',1]=_b[T]

reg total_amount_invested T
mat R[`row',2]=_b[T]

reg invested_above_minimum T
mat R[`row',3]=_b[T]


drop T temp r

display `row'

}

clear

svmat R

tab R1


gen test1=(R1>=.033 |R1<=-.033)

gen test2=(R2>=106|R2<=-106)

gen test3=(R3>=.037|R3<=-.037)

sum test* // Forth row of Table A6

**********************************
* Learning by (permutation test) *
**********************************

use Main_data, clear

keep if (Condition_A + Condition_B==1)&perceived!=.

set seed 1
set matsize 1000
mat R=J(1000,9,.)


forvalues row=1(1)1000 {

	gen r=runiform()

	xtile temp=r , n(43)

	gen T = (temp<=21)

	drop temp* 

	gen C2_X1 = T * perceived
	gen C2_X2 = T * (1-perceived)
	gen C1_X1 = (1-T) * perceived
	gen C1_X2 = (1-T) * (1-perceived)


	reg takeup C1_* C2_* , noc

	mat R[`row',1]=_b[C2_X1] - _b[C1_X1]
	mat R[`row',2]=_b[C2_X2] - _b[C1_X2]
	mat R[`row',3]=(_b[C2_X1] - _b[C1_X1]) - (_b[C2_X2] - _b[C1_X2])


	reg total_amount_invested C1_* C2_* , noc

	mat R[`row',4]=_b[C2_X1] - _b[C1_X1]
	mat R[`row',5]=_b[C2_X2] - _b[C1_X2]
	mat R[`row',6]=(_b[C2_X1] - _b[C1_X1]) - (_b[C2_X2] - _b[C1_X2])


	reg invested_above_minimum C1_* C2_* , noc

	mat R[`row',7]=_b[C2_X1] - _b[C1_X1]
	mat R[`row',8]=_b[C2_X2] - _b[C1_X2]
	mat R[`row',9]=(_b[C2_X1] - _b[C1_X1]) - (_b[C2_X2] - _b[C1_X2])




	drop C* T r 
	


display `row'

}


clear

svmat R

drop if R1==.

gen test1=(R1>=.017 |R1<=-.017)

gen test2=(R2>=.583|R2<=-.583)

gen test3=(R3>=.60|R3<=-.60)


gen test4=(R4>=222 |R4<=-222)

gen test5=(R5>=1750|R5<=-1750)

gen test6=(R6>=1527|R6<=-1527)


gen test7=(R7>=.145 |R7<=-.145)

gen test8=(R8>=.333|R8<=-.333)

gen test9=(R9>=.188|R9<=-.188)



mat Q=J(3,3,1)

forvalues x=1(1)3 {
summ test`x'
mat Q[`x',1]=r(mean)
}

forvalues x=4(1)6 {
summ test`x'
mat Q[`x'-3,2]=r(mean)
}

forvalues x=7(1)9 {
summ test`x'
mat Q[`x'-6,3]=r(mean)
}

mat li Q  // "Learning by" part of Table A.8, Panel B

************************************
* Learning from (permutation test) *
************************************

use Main_data, clear

keep if (Condition_A + Condition_B==1)&perceived!=.

set seed 1
set matsize 1000
mat R=J(1000,9,.)


forvalues row=1(1)1000 {

	gen r=runiform()

	xtile temp=r , n(43)

	gen T = (temp<=21)

	drop temp* 

	gen C2_X1 = T * friend_perceived
	gen C2_X2 = T * (1-friend_perceived)
	gen C1_X1 = (1-T) * friend_perceived
	gen C1_X2 = (1-T) * (1-friend_perceived)


	reg takeup C1_* C2_* , noc

	mat R[`row',1]=_b[C2_X1] - _b[C1_X1]
	mat R[`row',2]=_b[C2_X2] - _b[C1_X2]
	mat R[`row',3]=(_b[C2_X1] - _b[C1_X1]) - (_b[C2_X2] - _b[C1_X2])


	reg total_amount_invested C1_* C2_* , noc

	mat R[`row',4]=_b[C2_X1] - _b[C1_X1]
	mat R[`row',5]=_b[C2_X2] - _b[C1_X2]
	mat R[`row',6]=(_b[C2_X1] - _b[C1_X1]) - (_b[C2_X2] - _b[C1_X2])


	reg invested_above_minimum C1_* C2_* , noc

	mat R[`row',7]=_b[C2_X1] - _b[C1_X1]
	mat R[`row',8]=_b[C2_X2] - _b[C1_X2]
	mat R[`row',9]=(_b[C2_X1] - _b[C1_X1]) - (_b[C2_X2] - _b[C1_X2])




	drop C* T r 
	


display `row'

}


clear

svmat R

drop if R1==.

gen test1=(R1>=.38 |R1<=-.38)

gen test2=(R2>=.126|R2<=-.126)

gen test3=(R3>=.25|R3<=-.25)



gen test4=(R4>=1320 |R4<=-1320)

gen test5=(R5>=253|R5<=-253)

gen test6=(R6>=1066|R6<=-1066)


gen test7=(R7>=.329 |R7<=-0.329)

gen test8=(R8>=0|R8<=-0)

gen test9=(R9>=.329|R9<=-.329)





mat Q=J(3,3,1)

forvalues x=1(1)3 {
summ test`x'
mat Q[`x',1]=r(mean)
}

forvalues x=4(1)6 {
summ test`x'
mat Q[`x'-3,2]=r(mean)
}

forvalues x=7(1)9 {
summ test`x'
mat Q[`x'-6,3]=r(mean)
}

mat li Q  // "Learning from" part of Table A.8, Panel B


*************************************************************************************************************************

************
* TABLE A9 *
************

*This table replicates our main results in Table 2 of the main text, but using alternative outcome variables. Columns 1 and 2 replicate the regressions in columns 1 and 4 of Table 2 using the  amount invested in the asset instead of take-up rate as dependent variable. Columns 3 and 4 replicate the regressions in columns 1 and 4 of Table 2 using a dummy variable equal to one if the investor invested more than the minimum amount as the dependent variable.

clear *
use Main_data

*******************************
prog define Store, rclass
args column variables y
 {
	local row=1
	foreach x in `variables'  {
		cap mat TABLE_A9[`row',`column']=_b[`x'] 
		cap mat TABLE_A9[`row'+1,`column']=_se[`x']
			local ++row
			local ++row		
			local ++row				
	}
	
		mat TABLE_A9[20,`column']=e(N)
		mat TABLE_A9[21,`column']=e(r2)
		
		lincom Condition_C - Condition_B
		
		mat TABLE_A9[14,`column']=r(estimate)
		mat TABLE_A9[15,`column']=r(se)
				
		reg takeup c if Condition_A==1, noc

		mat TABLE_A9[17,`column']=_b[c]
		mat TABLE_A9[18,`column']=_se[c]		
	

}
end
*******************************

mat TABLE_A9=J(21,5,.)

reg total_amount Condition_B Condition_C Condition_A_neg if investor1==0, robust
Store 1 "Condition_B Condition_C Condition_A_neg"

xi: reg total_amount Condition_B Condition_C Condition_A_neg investor1  i.broker_id  i.office male single married age family [pw=weight], cluster(pair) robust
Store 2 "Condition_B Condition_C Condition_A_neg investor1"

reg invested_above Condition_B Condition_C Condition_A_neg if investor1==0, robust
Store 4 "Condition_B Condition_C Condition_A_neg"

xi: reg invested_above Condition_B Condition_C Condition_A_neg investor1  i.broker_id  i.office male single married age family [pw=weight], cluster(pair) robust
Store 5 "Condition_B Condition_C Condition_A_neg investor1"


mat li TABLE_A9




*************************************************************************************************************************

*************
* TABLE A10 *
*************

*This table replicates our results on heterogeneous social learning effects presented in Table 3 of the main text, but using an objective measure of investors' financial sophistication in place of the self-assessed measure used in the main text.
*The objective measure of financial sophistication is based on four financial literacy questions conducted in the follow-up survey. Investors who answered 3 or more questions correctly were classified as financially sophisticated. See Appendix C for an English version of the financial literacy questions.


clear *
set more off
use Main_data

*******************************
prog define Store, rclass
args column group
 {

gen X1=`group'==1
gen X2=`group'==0

foreach i in 1 2 {

gen C2_X`i' = Condition_B*X`i'

}

reg takeup X1 X2 [pw=weight] if Condition_A==1 & `group'!=., robust noc

		cap mat TABLE_A10[10,`column']=_b[X1] 
		cap mat TABLE_A10[11,`column']=_se[X1]

		cap mat TABLE_A10[10,`column'+1]=_b[X2] 
		cap mat TABLE_A10[11,`column'+1]=_se[X2]

test X1=X2

		cap mat TABLE_A10[10,`column'+2]=r(p)

reg takeup C2_X1 C2_X2 X1 if  `group'!=. & (Condition_A==1|Condition_B==1), robust

		cap mat TABLE_A10[1,`column']=_b[C2_X1] 
		cap mat TABLE_A10[2,`column']=_se[C2_X1]

		cap mat TABLE_A10[1,`column'+1]=_b[C2_X2] 
		cap mat TABLE_A10[2,`column'+1]=_se[C2_X2]

		test C2_X1= C2_X2
		cap mat TABLE_A10[1,`column'+2]=r(p)


xi: reg takeup C2_X*  X1 i.broker_id  i.office male single married age family [pw=weight] if (Condition_A+Condition_B==1) &  `group'!=., robust cluster(pair)

		cap mat TABLE_A10[6,`column']=_b[C2_X1] 
		cap mat TABLE_A10[7,`column']=_se[C2_X1]
		
		cap mat TABLE_A10[6,`column'+1]=_b[C2_X2] 
		cap mat TABLE_A10[7,`column'+1]=_se[C2_X2]

		test C2_X1= C2_X2
		cap mat TABLE_A10[6,`column'+2]=r(p)


drop *X1 *X2

}
end
*******************************


mat TABLE_A10=J(12,7,.)

Store 1 actual

****************************************************

Store 5 friend_actual

****************************************************


mat li TABLE_A10


*************************************************************************************************************************

*************
* TABLE A11 *
*************

*This table replicates our results on heterogeneous social learning effects presented in Table 3 of the main text, but using the amount invested in the asset instead of take-up rate as the dependent variable. 


clear *
set more off
use Main_data

*******************************
prog define Store, rclass
args column group
 {

gen X1=`group'==1
gen X2=`group'==0

foreach i in 1 2 {

gen C2_X`i' = Condition_B*X`i'

}

reg total_amount X1 X2 [pw=weight] if Condition_A==1 & `group'!=., robust noc

		cap mat TABLE_A11[10,`column']=_b[X1] 
		cap mat TABLE_A11[11,`column']=_se[X1]

		cap mat TABLE_A11[10,`column'+1]=_b[X2] 
		cap mat TABLE_A11[11,`column'+1]=_se[X2]

test X1=X2

		cap mat TABLE_A11[10,`column'+2]=r(p)

reg total_amount C2_X1 C2_X2 X1 if  `group'!=. & (Condition_A==1|Condition_B==1), robust

		cap mat TABLE_A11[1,`column']=_b[C2_X1] 
		cap mat TABLE_A11[2,`column']=_se[C2_X1]

		cap mat TABLE_A11[1,`column'+1]=_b[C2_X2] 
		cap mat TABLE_A11[2,`column'+1]=_se[C2_X2]

		test C2_X1= C2_X2
		cap mat TABLE_A11[1,`column'+2]=r(p)


xi: reg total_amount C2_X*  X1 i.broker_id  i.office male single married age family [pw=weight] if (Condition_A+Condition_B==1) &  `group'!=., robust cluster(pair)

		cap mat TABLE_A11[6,`column']=_b[C2_X1] 
		cap mat TABLE_A11[7,`column']=_se[C2_X1]
		
		cap mat TABLE_A11[6,`column'+1]=_b[C2_X2] 
		cap mat TABLE_A11[7,`column'+1]=_se[C2_X2]

		test C2_X1= C2_X2
		cap mat TABLE_A11[6,`column'+2]=r(p)


drop *X1 *X2

}
end
*******************************


mat TABLE_A11=J(12,7,.)

Store 1 perceived

****************************************************

Store 5 friend_perceived

****************************************************


mat li TABLE_A11



*************************************************************************************************************************

*************
* TABLE A12 *
*************

*This table replicates our results on heterogeneous social learning effects presented in Table 3 of the main text, but using a dummy variable equal to one if the investor invested more than the minimum amount instead of take-up rate as the dependent variable.


clear *
set more off
use Main_data

*******************************
prog define Store, rclass
args column group
 {

gen X1=`group'==1
gen X2=`group'==0

foreach i in 1 2 {

gen C2_X`i' = Condition_B*X`i'

}

reg invested_above X1 X2 [pw=weight] if Condition_A==1 & `group'!=., robust noc

		cap mat TABLE_A12[10,`column']=_b[X1] 
		cap mat TABLE_A12[11,`column']=_se[X1]

		cap mat TABLE_A12[10,`column'+1]=_b[X2] 
		cap mat TABLE_A12[11,`column'+1]=_se[X2]

test X1=X2

		cap mat TABLE_A12[10,`column'+2]=r(p)

reg invested_above C2_X1 C2_X2 X1 if  `group'!=. & (Condition_A==1|Condition_B==1), robust

		cap mat TABLE_A12[1,`column']=_b[C2_X1] 
		cap mat TABLE_A12[2,`column']=_se[C2_X1]

		cap mat TABLE_A12[1,`column'+1]=_b[C2_X2] 
		cap mat TABLE_A12[2,`column'+1]=_se[C2_X2]

		test C2_X1= C2_X2
		cap mat TABLE_A12[1,`column'+2]=r(p)


xi: reg invested_above C2_X*  X1 i.broker_id  i.office male single married age family [pw=weight] if (Condition_A+Condition_B==1) &  `group'!=., robust cluster(pair)

		cap mat TABLE_A12[6,`column']=_b[C2_X1] 
		cap mat TABLE_A12[7,`column']=_se[C2_X1]
		
		cap mat TABLE_A12[6,`column'+1]=_b[C2_X2] 
		cap mat TABLE_A12[7,`column'+1]=_se[C2_X2]

		test C2_X1= C2_X2
		cap mat TABLE_A12[6,`column'+2]=r(p)


drop *X1 *X2

}
end
*******************************


mat TABLE_A12=J(12,7,.)

Store 1 perceived

****************************************************

Store 5 friend_perceived

****************************************************


mat li TABLE_A12



*************************************************************************************************************************

*************
* TABLE A13 *
*************

*This table examines heterogeneous treatment effects depending on whether investor 1's and investor 2's share a family relationship; and, depending on the experience of the broker within the experiment.

*The table presents coefficients on the interactions of the variables at the column headings (relationship = family dummy variable; and, broker experience, respectively)  with the treatment effects of interest.
*These results are based on the regressions used in the full specification of column 4 from Table 2, but also including interactions of the group dummies (I_{c,i} in the notation of our empirical model, where c is the set of {Condition B, Condition C, Condition A^neg, Investor 1}) with the family relationship or broker experience variable. We also include the main effect of the variable of the family relationship or broker experience variable.
*In column 1, we interact the group dummies with a dummy variable equal to one if the investors 1 and 2 are family members. The omitted category is "friends".  In column 2, we interact the group dummies with a variable indicating the number of calls that the broker had made before the day of the call.

clear *
set more off
use Main_data

*******************************
prog define Store, rclass
args column group
 {

preserve

gen B_int = Condition_B*`group'
gen C_int = Condition_C*`group'
gen A_neg_int = Condition_A_neg*`group'
gen investor1_int = investor1*`group'


xi: reg takeup B_int C_int A_neg_int investor1_int `group' Condition_B Condition_C Condition_A_neg investor1 i.broker i.office male single married age family  [pw=weight], cluster(pair)


		cap mat TABLE_A13[1,`column']=_b[B_int] 
		cap mat TABLE_A13[2,`column']=_se[B_int]


		cap mat TABLE_A13[4,`column']=_b[C_int] 
		cap mat TABLE_A13[5,`column']=_se[C_int]

		lincom C_int-B_int		
		cap mat TABLE_A13[7,`column']=r(estimate) 
		cap mat TABLE_A13[8,`column']=r(se)

restore
}
end
*******************************

mat TABLE_A13=J(8,2,.)

Store 1 family

****************************************************

Store 2 intbeforetoday

****************************************************

mat li TABLE_A13

*************
*************


